# Generated by Django 4.2.10 on 2024-03-05 15:17

import colorfield.fields
from django.db import migrations, models
from django.db.utils import ProgrammingError


class Migration(migrations.Migration):
    dependencies = [
        ("paweljong", "0027_paweljongglobalpermissions"),
    ]

    # This migration must run after Core's migration 1 through 60, but before
    #  61. That's because we are in fact moving a model, and we need to make sure
    #  that this migration runs at the right time.
    recorder = migrations.recorder
    applied = False
    try:
        applied = recorder.MigrationRecorder.Migration.objects.filter(app="paweljong", name="0028_add_eventadditionalfield").exists()
    except ProgrammingError:
        applied = False
    if not applied:
        dependencies.append(("core", "0060_person_unique_short_name_email"))
        run_before = [
            ("core", "0061_remove_group_additional_fields"),
        ]


    operations = [
        migrations.CreateModel(
            name="EventAdditionalField",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "managed_by_app_label",
                    models.CharField(
                        blank=True,
                        editable=False,
                        max_length=255,
                        verbose_name="App label of app responsible for managing this instance",
                    ),
                ),
                ("extended_data", models.JSONField(default=dict, editable=False)),
                (
                    "title",
                    models.CharField(max_length=255, verbose_name="Title of field", unique=True),
                ),
                (
                    "field_type",
                    models.CharField(
                        choices=[
                            ("BooleanField", "Boolean (Yes/No)"),
                            ("CharField", "Text (one line)"),
                            ("DateField", "Date"),
                            ("DateTimeField", "Date and time"),
                            ("DecimalField", "Decimal number"),
                            ("EmailField", "E-mail address"),
                            ("IntegerField", "Integer"),
                            ("GenericIPAddressField", "IP address"),
                            ("NullBooleanField", "Boolean or empty (Yes/No/Neither)"),
                            ("TextField", "Text (multi-line)"),
                            ("TimeField", "Time"),
                            ("URLField", "URL / Link"),
                        ],
                        max_length=50,
                        verbose_name="Type of field",
                    ),
                ),
                (
                    "required",
                    models.BooleanField(default=False, verbose_name="Required"),
                ),
                (
                    "help_text",
                    models.TextField(
                        blank=True, verbose_name="Help text / description"
                    ),
                ),
            ],
            options={
                "verbose_name": "Addtitional field for events",
                "verbose_name_plural": "Addtitional fields for events",
            },
        ),
        migrations.AddField(
            model_name="event",
            name="additional_fields",
            field=models.ManyToManyField(
                blank=True,
                to="paweljong.eventadditionalfield",
                verbose_name="Additional fields",
            ),
        ),
        # Migrate data from Core table; deletion will be handled by Core
        migrations.RunSQL(
            """
            -- Copy additional fields from core if table exists and relations to Group model as relation to respective Event model
            DO $$BEGIN INSERT INTO paweljong_eventadditionalfield (id, title, field_type, help_text, required, extended_data, managed_by_app_label) SELECT id, title, field_type, help_text, required, extended_data, ('') AS managed_by_app_label FROM core_additionalfield;
            INSERT INTO paweljong_event_additional_fields (id, event_id, eventadditionalfield_id) SELECT id, (SELECT event.id FROM paweljong_event AS event WHERE event.linked_group_id = group_additionalfield.group_id) AS event_id, additionalfield_id AS eventadditionalfield_id FROM core_group_additional_fields AS group_additionalfield;
            EXCEPTION WHEN undefined_table THEN NULL;
            END$$;
            """
        ),
    ]
